==> osgi-adapter-2.1.39-sources.jar: org/jvnet/hk2/osgiadapter/OsgiPopulatorPostProcessor.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2007-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.jvnet.hk2.osgiadapter;

import static org.jvnet.hk2.osgiadapter.Logger.logger;

import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.logging.Level;

import org.glassfish.hk2.api.HK2Loader;
import org.glassfish.hk2.api.MultiException;
import org.glassfish.hk2.api.ServiceLocator;
import org.glassfish.hk2.bootstrap.PopulatorPostProcessor;
import org.glassfish.hk2.utilities.DescriptorImpl;

/**
 * A PopulatorPostProcessor that sets the HK2Loader prior to binding a descriptor
 * 
 * @author mason.taube@oracle.com
 *
 */
public class OsgiPopulatorPostProcessor implements
		PopulatorPostProcessor {
	
	private final OSGiModuleImpl osgiModule;

	OsgiPopulatorPostProcessor(OSGiModuleImpl osgiModule) {
		this.osgiModule = osgiModule;	
	}

	@Override
	public DescriptorImpl process(DescriptorImpl descriptorImpl) {
        HK2Loader hk2Loader = new HK2Loader() {

			@SuppressWarnings({ "unchecked", "rawtypes" })
			@Override
			public Class<?> loadClass(final String className)
					throws MultiException {
                osgiModule.start();
				return (Class<?>) AccessController.doPrivileged(new PrivilegedAction() {
					public java.lang.Object run() {
						try {
							return osgiModule.getBundle().loadClass(className);
						} catch (Throwable e) {
							logger.logp(Level.SEVERE, "OSGiModuleImpl",
									"loadClass",
									"Exception in module " + osgiModule.getBundle().toString(), e);

							throw new MultiException(e);
						}
					}
				});

			}
        	
        };
		descriptorImpl.setLoader(hk2Loader);
		return descriptorImpl;
	}	
}

==> osgi-adapter-2.1.41-sources.jar: org/jvnet/hk2/osgiadapter/OsgiPopulatorPostProcessor.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2007-2012 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.jvnet.hk2.osgiadapter;

import static org.jvnet.hk2.osgiadapter.Logger.logger;

import java.security.AccessController;
import java.security.PrivilegedAction;
import java.util.logging.Level;

import org.glassfish.hk2.api.HK2Loader;
import org.glassfish.hk2.api.MultiException;
import org.glassfish.hk2.bootstrap.PopulatorPostProcessor;
import org.glassfish.hk2.utilities.DescriptorImpl;

/**
 * A PopulatorPostProcessor that sets the HK2Loader prior to binding a descriptor
 * 
 * @author mason.taube@oracle.com
 *
 */
public class OsgiPopulatorPostProcessor implements
		PopulatorPostProcessor {
	
	public static final String BUNDLE_VERSION = "Bundle-Version";
	public static final String BUNDLE_SYMBOLIC_NAME = "Bundle-SymbolicName";
	private final OSGiModuleImpl osgiModule;

	OsgiPopulatorPostProcessor(OSGiModuleImpl osgiModule) {
		this.osgiModule = osgiModule;	
	}

	@Override
	public DescriptorImpl process(DescriptorImpl descriptorImpl) {
        HK2Loader hk2Loader = new HK2Loader() {

			@SuppressWarnings({ "unchecked", "rawtypes" })
			@Override
			public Class<?> loadClass(final String className)
					throws MultiException {
                osgiModule.start();
				return (Class<?>) AccessController.doPrivileged(new PrivilegedAction() {
					public java.lang.Object run() {
						try {
							return osgiModule.getBundle().loadClass(className);
						} catch (Throwable e) {
							logger.logp(Level.SEVERE, "OSGiModuleImpl",
									"loadClass",
									"Exception in module " + osgiModule.getBundle().toString(), e);

							throw new MultiException(e);
						}
					}
				});

			}
        	
        };
		descriptorImpl.setLoader(hk2Loader);
		
		descriptorImpl.addMetadata(BUNDLE_SYMBOLIC_NAME,osgiModule.getBundle().getSymbolicName());
		descriptorImpl.addMetadata(BUNDLE_VERSION, osgiModule.getBundle().getVersion().toString());
		return descriptorImpl;
	}	
}
